package statej.ast;

import statej.Visitor;

import statej.typeChecker.MethodSymbol;
import statej.typeChecker.Modifier;
import statej.utils.ParamUtils;

/**
 * <p>Title: Programming mini project 2 Java-- compiler</p>
 * <p>Description: </p>
 * <p>Copyright: Copyright (c) 2004 NIcholas Cameron</p>
 * <p>Company: </p>
 * @author Nicholas Cameron
 * @version 1.0
 */

public class MethodNode extends SlotNode
{
    protected ListNode params;
    protected boolean synch;
    protected String asState;
    private CompoundNode body;

    private MethodSymbol symbol = null;

    public MethodNode(String name, ListNode params, Modifier access, String type, boolean synch, CompoundNode body, int lineNumber, int colNumber)
    {
        this (name, null, params, access, type, synch, body, lineNumber, colNumber);
    }

    public MethodNode(String name, String asState, ListNode params, Modifier access, String type, boolean synch, int lineNumber, int colNumber)
    {
        this (name, asState, params, access, type, synch, null, lineNumber, colNumber);
    }

    private  MethodNode(String name, String asState, ListNode params, Modifier access, String type, boolean synch, CompoundNode body, int lineNumber, int colNumber)
    {
        super(name, access, type, lineNumber, colNumber);
        this.params = params;
        this.body = body;
        this.synch = synch;
        this.asState = asState;
    }

    public Object accept(Visitor v)
    {
        return v.visit(this);
    }

    public Object[] visitParams(Visitor v)
    {
        if (params == null)
            return new Object[0];

        Node[] paramList = params.toArray();
        Object[] result = new Object[paramList.length];
        for (int i = 0; i < paramList.length; ++i)
            result[i] = paramList[i].accept(v);

        return result;
    }

    public String toString()
    {
    	String synchStr = synch ? " synchronized" : "";
    	String asString = asState == null ? "" : " as " + asState;
        return access + synchStr + " " + name + "(" + ParamUtils.makeSourceList(params) + ")" + asString;
    }
    
    public String[] getParamNames()
    {
    	if (params == null)
    		return new String[0];
    	
    	Node[] pNodes = params.toArray();
    	String[] names = new String[pNodes.length];
    	for (int i = 0; i < names.length; ++i)
    	{
    		names[i] = ((ArgNode)pNodes[i]).getName();
    	}
    	
    	return names;
    }

    public Object visitBody(Visitor v)
    {
        if (body != null)
            return body.accept(v);
        
        return null;
    }

    public String getType()
    {
        return type;
    }

    public void setParams(ListNode params)
    {
        this.params = params;
    }

    public void setSymbol(MethodSymbol symbol)
    {
        this.symbol = symbol;
    }

    public MethodSymbol getSymbol()
    {
        return symbol;
    }
    public String eol()
    {
    	throw new RuntimeException("non-promotable expression");
    }
    
    public boolean isSynchonized()
    {
    	return synch;
    }
    
//    public void setBody(CompoundNode body)
//    {
//    	this.body = body;
//    }
    
    public CompoundNode getBody()
    {
    	return body;
    }
    
    public String getAsState()
    {
    	return asState;
    }
}