package statej.ast;

import statej.Visitor;

public class ProgramNode extends Node
{
	protected ListNode importList;
	protected ListNode classList;
	protected PackageNode pack;
	
	public ProgramNode(PackageNode pack, ListNode importList, ListNode classList)
	{
		super(0, 0);
		this.importList = importList;
		this.classList = classList;
		this.pack = pack;
	}
	
	public Object accept(Visitor v)
	{
		return v.visit(this);
	}
	
	public Object visitPackage(Visitor v)
	{
		if (pack == null)
			return null;
		
		return pack.accept(v);
	}
	
	public Object[] visitImports(Visitor v)
	{
		if (importList == null)
			return new Object[0];
		
		Node[] nodes = importList.toArray();
		Object[] result = new Object[nodes.length];
		for (int i = 0; i < nodes.length; ++i)
		{
			result[i] = nodes[i].accept(v);
		}
			
		return result;
	}
	
	public Object[] visitClasses(Visitor v)
	{
		Node[] nodes = classList.toArray();
		Object[] result = new Object[nodes.length];
		for (int i = 0; i < nodes.length; ++i)
		{
			result[i] = nodes[i].accept(v);
		}
			
		return result;
	}

	public String toString()
	{
		if (pack == null)
			return "Program: " + importList.size() + " import statements and " + classList.size() + " classes.\n\n" + importList + "\n" + classList;
		else
			return "Program: " + importList.size() + " import statements and " + classList.size() + " classes.\n\n" + pack + "\n" + importList + "\n" + classList;
	}
	
    public String eol()
    {
    	throw new RuntimeException("non-promotable expression");
    }
}
