package statej.utils;

/**
 *
 * <p>Title: DBConnect Framework</p>
 * <p>Description: </p>
 * <p>Copyright: Copyright (c) 2004 Merchant Internet</p>
 * <p>Company: Merchant Internet</p>
 * @author Nicholas Cameron
 * @version 1.0
 */


public class StringUtils
{
    /**
     * formats a String by escaping apostrophes for insertion in a DB
     * converts all occurances of ' with //'
     * @return the String representation of this FormatedString
     */
    public static String escapeApostrophes(String input)
	{
		String modText = "";

        for (int i = 0; i < input.length(); i++)
        {
            if (input.substring(i, i+1).equals("'"))
                modText += "\\'";
            else
                modText += input.charAt(i);
        }

        return modText;
	}

    /**
     * Parses a String, if it finds a newline (/n) it replaces it with a <BR> tag
     * @return the String for HTML display display
     */
    public static String paragraphForHTML(String input)
    {
        String result = replace("\r\n", "<BR>", input);
        result = replace("\n", "<BR>", result);
        result = replace("\r", "<BR>", result);

        return result;
    }

  /**
   * Method to replace all occurences of a String within another
   * String, with a third String, i.e.
   * <PRE>replace("Mr","Prof","Dear Mr X");
   * =Dear Prof X</PRE>
   * Note that the methods replaces <B>all</B> occurences.
   *
   * @param toReplace   The string to be replaced.
   * @param replaceWith The string that will replace the above.
   *                    Note that this string doesn't have to be
   *                    the same size.
   * @param wholeString The initial string.
   *
   * @returns           The String with all replacements made.
   */
   public static String replace(String toReplace,String replaceWith,String wholeString)
   {
       //error checking
       if ((toReplace==null) || (wholeString==null))
           return wholeString;

       String temp = replaceSingle(toReplace,replaceWith,wholeString);
       while (!temp.equals(wholeString))
       {
           wholeString=temp;
           temp = replaceSingle(toReplace,replaceWith,wholeString);
       }

       return temp;
   }

   //helper method for replace()
    private static String replaceSingle(String toReplace,String replaceWith,String wholeString)
    {
        String result = wholeString;

        //find first instance of toReplace
        int start = wholeString.indexOf(toReplace);
        if (start==-1)
            return result;

        //work out where to start again
        int end = start+toReplace.length();

        return wholeString.substring(0,start) +
                replaceWith +
                wholeString.substring(end);
    }

    /**
     * returns a String with anything after the first . stripped
     * eg foo.doc --> foo, bar --> bar
     * @param input the input String
     * @return the input string with no extension
     */
    public static String removeExtension(String input)
    {
        int dotPos = input.indexOf('.');
        if (dotPos < 0)
            return input;

        return input.substring(0, dotPos);
    }

    //tests
    public static void main(String[] args)
    {
        String test1 = "Nick's apostrophe. One' Two'' Three'''ne";
        System.out.println(test1 + "\n" + StringUtils.escapeApostrophes(test1));
        System.out.println(test1 + "\n" + StringUtils.replace("ne", "xen", test1));

        String test2 = "Line\nLine\nLine\n";
        System.out.println(test2 + StringUtils.paragraphForHTML(test2));
    }
}